@@ -1,4 +1,4 @@
-__version__ = '1.1.5'
+__version__ = '1.1.6'
 
 import requests
 import json
@@ -65,34 +65,36 @@ class StreamBot:
     def chat(self, messages = []):
         reqBody = self.build_req_body(messages)
         reqHeaders = {
-            'Accept': 'text/event-stream',
-            'Authorization': 'Bearer ' + self.api_key
+          'Accept': 'text/event-stream',
+          'Authorization': f'Bearer {self.api_key}'
         }
         result = None
         try:
             # Fire off conversation message array to OpenAI  
-            response = requests.post(self.openai_url, stream=True, headers=reqHeaders, json=reqBody)
-            # Using the Server Sent Events library to support "Stream" of tokens to simulate the AI typing out
-            client = sseclient.SSEClient(response)
+            with requests.post(self.openai_url, stream=True, headers=reqHeaders, json=reqBody) as response:
+              # Using the Server Sent Events library to support "Stream" of tokens to simulate the AI typing out
+              client = sseclient.SSEClient(response)
             # Array to capture the tokens since `response` will no longer be consumable
-            response_text = []
-            for event in client.events():
-                try:
-                    # Wrapped in try because json.loads fails due to `choices` not being present in last event
-                    data = json.loads(event.data)['choices'][0]
-                    if self.verbosity >= 3:
-                      print(data)
-                    # In first event, `delta` doesn't exist, so we check if the ['delta']['content'] keys are present
-                    # Also check for ['finish_reason'] to break on last message
-                    if 'delta' in data and 'role' in data['delta']:
-                        print(self.bot_name + ": ")
-                    if 'delta' in data and 'content' in data['delta'] and data['finish_reason'] != 'stop':
-                        response_text.append(data['delta']['content'])
-                        print(data['delta']['content'], end="", flush=True)
-                except json.decoder.JSONDecodeError as e:
-                    if self.verbosity >= 3:
-                        print(f"JSON Decoder Error: {e}")
-                    pass
+              response_text = []
+              for event in client.events():
+                  try:
+                      data = json.loads(event.data)
+                      if data.get('choices',{}):
+                        # Wrapped in try because json.loads fails due to `choices` not being present in last event
+                        choices = data['choices'][0]
+                        if self.verbosity >= 3:
+                          print(choices)
+                        # In first event, `delta` doesn't exist, so we check if the ['delta']['content'] keys are present
+                        # Also check for ['finish_reason'] to break on last message
+                        if choices.get('delta',{}).get('role',{}):
+                            print(self.bot_name + ": ")
+                        if choices.get('delta',{}).get('content') and choices['finish_reason'] != 'stop':
+                            response_text.append(choices['delta']['content'])
+                            print(choices['delta']['content'], end="", flush=True)
+                  except json.decoder.JSONDecodeError as e:
+                      if self.verbosity >= 3:
+                          print(f"JSON Decoder Error: {e}")
+                      pass
         except requests.exceptions.RequestException as e:
             if self.verbosity >= 3:
               print(f"Requests Error: {e}")
@@ -114,21 +116,21 @@ class StreamBot:
       try:
           # Fire off conversation message array to OpenAI  
           response = requests.post(self.openai_url, stream=True, headers=reqHeaders, json=reqBody)
-          if self.verbosity >= 1:
-            print(response)
           # Using the Server Sent Events library to support "Stream" of tokens to simulate the AI typing out
           client = sseclient.SSEClient(response)
           # Array to capture the tokens since `response` will no longer be consumable
           for event in client.events():
               try:
-                  # Wrapped in try because json.loads fails due to `choices` not being present in last event
-                  data = json.loads(event.data)['choices'][0]
-                  # In first event, `delta` doesn't exist, so we check if the ['delta']['content'] keys are present
-                  # Also check for ['finish_reason'] to break on last message
-                  if 'delta' in data and 'role' in data['delta']:
-                      yield '[START_OF_STREAM]' #Helper string to know when to render new chat content
-                  if 'delta' in data and 'content' in data['delta'] and data['finish_reason'] != 'stop':
-                      yield data['delta']['content']
+                  data = json.loads(event.data)
+                  if data.get('choices',{}):
+                    # Wrapped in try because json.loads fails due to `choices` not being present in last event
+                    choices = data['choices'][0]
+                    # In first event, `delta` doesn't exist, so we check if the ['delta']['content'] keys are present
+                    # Also check for ['finish_reason'] to break on last message
+                    if choices.get('delta',{}).get('role',{}):
+                        yield '[START_OF_STREAM]' #Helper string to know when to render new chat content
+                    if choices.get('delta',{}).get('content') and choices['finish_reason'] != 'stop':
+                        yield choices['delta']['content']
               except json.decoder.JSONDecodeError:
                   pass
       except requests.exceptions.RequestException as e:
